module.exports = defineTest({
	description: 'keeps logical expressions if the first part is reassigned'
});
